#!/usr/bin/perl
#---------------------------------------------------------------
#  Module          : BleriotFontTest
#  File            : BleriotFontTest.pl
#
#  Copyright (C) 2002
#  Centre d'tudes de la Navigation Arienne
#  Authors: Vinot Jean-Luc <vinot@cena.fr>
#
#---------------------------------------------------------------

use Tk;
use Tk::Zinc;
use Getopt::Long;
use strict 'vars';

$| = 1;

my %opt;
my $title;
my $cp;

my %fonts = ('m10' => 'bleriot-radar-m10',
	     'm12' =>'bleriot-radar-m12',
	     'm14c' => 'bleriot-radar-m14c',
	     'm14' =>'bleriot-radar-m14',
	     'b14c' => 'bleriot-radar-b14c',
	     'b14' => 'bleriot-radar-b14',
	     'm15c' => 'bleriot-radar-m15c',
	     'm15' => 'bleriot-radar-m15',
	     'b15c' => 'bleriot-radar-b15c',
	     'b15' => 'bleriot-radar-b15',
	     'm16c' => 'bleriot-radar-m16c',
	     'm16' => 'bleriot-radar-m16',
	     'b16c' => 'bleriot-radar-b16c',
	     'b16' => 'bleriot-radar-b16',
	     'm17c' => 'bleriot-radar-m17c',
	     'm17' => 'bleriot-radar-m17',
	     'm18c' => 'bleriot-radar-m18c',
	     'm18' => 'bleriot-radar-m18',
	     'm20c' => 'bleriot-radar-m20c',
	     'm20' => 'bleriot-radar-m20',
	     'm22c' => 'bleriot-radar-m22c',
	     'm22' => 'bleriot-radar-m22',
	     'm24c' => 'bleriot-radar-m24c',
	     'm24' => 'bleriot-radar-m24',
	     'b24c' => 'bleriot-radar-b24c',
	     'b24' => 'bleriot-radar-b24',
	     'm40' => 'bleriot-radar-m40',
	     'm80' => 'bleriot-radar-m80',
	     );

my @corps = (10, 12, 14, 15, 16, 17, 18, 20, 22, 24);
my @graisses = (['m', 'Medium'], ['b', 'SemiBold']);
my @chasses = (['', 'Normal'], ['c', 'Condensed']);

my @balcolor = ('#000000', '#4068e0');

my $numeric = '0123456789';
my $capital = 'ABCDEFGHIJKLMNOPQRSTUVWXYZ';
my $lowercase = 'abcdefghijklmnopqrstuvwxyz';
my $capaccent = "\xC0\xC2\xC7\xC8\xC9\xCA\xCB\xCE\xCF\xD4\xD9\xDB";
my $accent = '';
my $tendancy = "\x14\x15\x16";  #caractres hexa 14, 15 et 16
my $div = '!"#$%&'."'".'()*+,-./:;<=>?@[\]^_{|}'."\xB0"; #\xA4

my %glyphsets = (alphanum => [$capital.'  '.$tendancy,
			      $numeric.'  '.$lowercase,
			     ],

		 extent => [$numeric.'  '.$capital,
			    $lowercase.' '.$capaccent.' '.$accent,
			    $tendancy, #.' '.$div,
			    ],
		 extent => [$numeric,
			    $capital.' '.$capaccent,
			    $lowercase.' '.$accent,
			    $tendancy.' '.$div,
			    ],
		);

my $alphabet = $numeric.$capital.$lowercase.$tendancy.$div;
my $alphabet2 = $numeric.$capital.$lowercase;

my ($width, $height) = (1400, 1100);

# creation de la fenetre principale
my $mw = MainWindow->new();

$mw->geometry($width.'x'.$height.'+0+0');
$title = "Test fontes : Bleriot-radar";
$mw->title($title);


#------------------------
# creation du widget Zinc
my $zinc = $mw->Zinc(-render => 0,
		     -width => $width,
		     -height => $height,
		     -backcolor => '#dddddd',
		     -borderwidth => 0,
		     -lightangle => 130,
		     );

$zinc->pack(-fill => 'both', -expand => 1);

my ($x, $y) = (40, 0);
my $index = 0;
my $margin = 10;
my $subtitle_font = "bleriot-radar-m17";

foreach my $graisse (@graisses) {
  foreach my $chasse (@chasses) {

    my ($g_symbol, $g_name) = @{$graisse};
    my ($c_symbol, $c_name) = @{$chasse};
    my $subtitle = "Bleriot Radar ".$g_name." ".$c_name;

    # test bounding box titre
    my ($tw0, $ystep) = &stringBBox($subtitle_font, $subtitle);

    $y += 30;
 
    $zinc->add('text', 1,
	       -position => [$x, $y],
	       -color => '#0000ee',
	       -font => $subtitle_font,
	       -text => $subtitle,
	       -anchor => 'w',
	       -visible => 1,
	      );

    $y += ($ystep + 10);

    foreach my $size (@corps) {

      my $fontsymbol = $g_symbol.$size.$c_symbol;

      if (exists $fonts{$fontsymbol}) {
	my $fontname = "bleriot-radar-".$graisse->[0].$size.$chasse->[0];
	# test bounding box fonte
	my ($tw0, $ystep) = &stringBBox($fontname, $alphabet);
	my $width = $tw0 + ($margin * 2);
	
	$index++;

	my $text = $alphabet;
	if  ($size eq 'm40' or $size eq 'm80') {
	  $text = $alphabet2;
	
	  $y -= ($size eq 'm40') ? $ystep/2 : $ystep*.7;
	}

	$zinc->add('text', 1,
		   -position => [$x+40, $y],
		   -font => $subtitle_font,
		   -text => $size." :",
		   -color => '#777777',
		   -alignment => 'right',
		   -anchor => 'e',
		   -visible => 1,
		  );

	$zinc->add('text', 1,
		   -position => [$x+60, $y],
		   -font => $fontname,
		   -text => $text,
		   -anchor => 'w',
		   -visible => 1,
		  );

	$y += ($ystep*.7 + 12);
      }
    }

  }
}


MainLoop;



sub stringBBox {
  my ($font, $str, $sw, $sh) = @_;
  $sw = 0 if !defined $sw;
  $sh = 0 if !defined $sh;


  if (ref($str) eq 'ARRAY') {
    my @strings = @{$str};
    $str = shift @strings;

    if (@strings) {
      my ($sw1, $sh1) = &stringBBox($font, \@strings, $sw, $sh);

      $sw = $sw1 if $sw1 > $sw;
      $sh = $sh1 if $sh1 > $sh;
    }

  }

  my $test = $zinc->add('text', 1,
			-position => [0, 0],
			-font => $font,
			-text => $str,
			-visible => 0,
		       );

  my ($x0, $y0, $x1, $y1) = $zinc->bbox($test);
  $zinc->remove($test);

  $sw = ($x1 - $x0) if ($x1 - $x0) > $sw;
  $sh = ($y1 - $y0) if ($y1 - $y0) > $sh;

  return ($sw, $sh);

}
