#!/usr/bin/perl -w 

# script utilis pour gnrer les images de la documentation du paquet bleriot-fonts


require 5.004 ;

use strict;
use Tk;
use Getopt::Long;


my $snapshoots = 0;
&check_options;
################# les constantes et les variables "constantes"

my $BACKGROUND = "#bbbbbb";
my $FOREGROUND = '#000000';

################# les variables globales
my @fonts = qw( bleriot-radar-m8 bleriot-radar-m8c
		bleriot-radar-m10 bleriot-radar-m10c
		bleriot-radar-m12 bleriot-radar-m12c
		bleriot-radar-m14 bleriot-radar-m14c bleriot-radar-b14 bleriot-radar-b14c
		bleriot-radar-m15 bleriot-radar-m15c bleriot-radar-b15 bleriot-radar-b15c
		bleriot-radar-m16 bleriot-radar-m16c bleriot-radar-b16 bleriot-radar-b16c
		bleriot-radar-m17 bleriot-radar-m17c
		bleriot-radar-m18 bleriot-radar-m18c 
		bleriot-radar-m20 bleriot-radar-m20c
		bleriot-radar-m22 bleriot-radar-m22c
		bleriot-radar-m24 bleriot-radar-m24c bleriot-radar-b24 bleriot-radar-b24c 
		bleriot-radar-m40
		bleriot-radar-m80
		);

my @configs;
foreach my $f (@fonts) {
    my ($size,$condensed) = $f =~ /-[a-z](\d+)(c?)/ ;
    my $lin1 = 20;
    my $lin2 = 20+$size;
    my $col1 = 15;
    my $col2 = $col1 + 15 + $size*5;
    my $col3 = $col2 + 15 + $size*2;
    my $windowHeight = 30+ 3*$size;
    my $windowWidth = 50 + 11*$size;
    
    push (@configs, $f, [$windowWidth,$windowHeight, "",
			 $col1,$lin1, "AFR2409", $col2,$lin1, "190", $col3,$lin1,"LFPG",
			 $col1,$lin2, "BAW3567", $col2,$lin2, "111", $col3,$lin2,"WWWW"]);
}


if ($snapshoots) {
    open HTML, ">index.html";
    print HTML "<!DOCTYPE HTML PUBLIC \"-//IETF//DTD HTML//EN\">
<html>
<head>
  <title>Snapshots of all fonts included in the bleriot-fonts package</title>
  <meta name=\"keywords\" content=\"CENA ATC PII air traffic control fonts bleriot orly toccata\">
</head>
<body>
<h1>Snapshots of all fonts included in the bleriot-fonts package</h1>
All images of this page have been automaticaly generated with the help of a perl script (<samp>create_html_info.pl</samp>, freely available in the source package) and the imagemagick package.
<p>
";
}

	
my $prevsize = 0;
while (@configs) {
    my $font = shift @configs;
    my ($size) = $font =~ /-[a-z](\d+)c?/ ;
    if ($snapshoots and $prevsize != $size) {
	print HTML "<br>\n<h3>size $size fonts</h3>\n";
	$prevsize = $size;
    }
    
    my ($X,$Y, $commentstring, @datas) = @{shift (@configs)};
    &create_image ($X,$Y,$font,$commentstring,@datas);

}
    
if ($snapshoots) {
    print HTML "<hr>
<div align=right><font size=-1><i>
<!-- Created: Mon Dec 2 2002 -->
Last automatic generation: " . localtime() . "
</i></font></div>
  </body>
</html>
";
}

sub create_image {
    my ($X, $Y, $font, $comment, @data) = @_;
    my $mw = MainWindow->new;
    $mw->title($font);

    my $dy = 0;
    if ($comment ne "") {
	$comment = "(".$comment.")";
	$dy = 15;
    }
    my $strlength = length($font) * 8 + 10;
    my $strlength2 = length($comment) * 8 + 10;
    $strlength = $strlength2 if ($strlength < $strlength2);
    $X = $strlength if ($X < $strlength);
    $Y += $dy;
    
    my $im = $mw->Canvas (-width, $X, -height, $Y, -background, $BACKGROUND);
    $im->pack;

    print HTML "<img alt=\"$font\" src=\"$font.png\" WIDTH=".($X+2)." HEIGHT=".($Y+2)." BORDER=1>\n" if ($snapshoots);

    $im->create ('text', 5, 3, -text, $font, -anchor, "nw", -font, "8x13", -fill, $FOREGROUND);
    $im->create ('text', 5, 3+$dy,
		 -text, $comment,
		 -anchor, "nw",
		 -font, "8x13",
		 -fill, $FOREGROUND) if ($comment);
    while (@data) {
	my $x = shift @data; 
	my $y = shift @data; 
	my $text = shift @data; 
	$im->create ('text', $x, $y+10+$dy, -text, $text, -anchor, "nw", -font, $font, -fill, $FOREGROUND);
    }
    
    $mw->update;
    if (!$snapshoots) {
    }
    else {
	system ("import", -window, $mw->id, $font.".png");
	$mw->destroy;
    }
}

MainLoop if (!$snapshoots);


sub check_options {
    # on traite la ligne de commande
    my ($opt_help);
    GetOptions("help" => \$opt_help,
	       "snap"    => \$snapshoots,
	       );

    &usage if ($opt_help && $opt_help);
}

sub usage {
    print "create_html_info.pl [-h] [-snap]\n";
    print "   create_html_info.pl is a simple application for displaying\n";
    print "   and/or snapping all fonts of the package with representative pieces of text\n"; 
    print " options are:\n";
    print "   -h            to give you this simple help\n";
    print "   -snap    to produce png file (needs imagemagick package)\n";
    exit;
}
