#!/usr/bin/perl -w

# this script takes a list of bdf files as parameters and generates an alias file
# from the following properties of the bdf files:
# FAMILY_NAME
# WEIGHT_NAME
# PIXEL_SIZE
# SETWIDTH_NAME
# SLANT

# it also verify that :
#  - there is only one FONT field in the whole file,
#  - there is a copyright notice
#  - comments includes a cvs version information
#  - comments give a full licence (NOT YET VERIFIED!)

use strict;


my @bdfs = @ARGV;

my $error = 0;

foreach my $bdf (@bdfs) {
    unless ( open (BDF , $bdf) ) {
	print STDERR "unable to open $bdf\n";
	next;
    }
#    print "OPENING $bdf\n";
    my $fullname;
    my $copyright = "";
    my $font_count = 0;
    my @font;
    my $slant = "";
    my $family_name = "";
    my $weight_name = "";
    my $setwidth_name = "";
    my $pixel_size = "";
    my $glyphe_count = 0;
    my $width_sum = 0;
    my $average_width = 0;
    my $include_file_version = 0;
    while (<BDF>) {
	if ( /^COMMENT\s+.*Version\s+\$Id/ ) {
	    $include_file_version = 1;
	}
	if ( /^COPYRIGHT\s+"(.+)"/ ) {
	    $copyright = $1;
#	    print "copyright: $copyright\n";
	    if ($copyright !~ /(C).*CENA/) {
		print STDERR "Error the COPYRIGHT field does not contain (C) and CENA\n";
	        $error++;
	    }
	}
	elsif ( /^FONT\s+(.+)/ ) {
	    $font_count++;
	    push @font, $1;
#	    print "FONT: $1\n";
	    if ($1 =~ /^(-.*)/) {
		$fullname = $1;
	    }
	}
	elsif ( /^FAMILY_NAME\s+"(.+)"/ ) {
	    $family_name = $1;
	    $family_name =~ s/\s/-/g ;
	    $family_name = lc($family_name);
#	    print "family_name: $family_name\n";
	}
	elsif ( /^WEIGHT_NAME\s+"(.+)"/ ) {
	    $weight_name = lc($1);
#	    print "weight_name: $weight_name\n";
	}
	elsif ( /^SETWIDTH_NAME\s+"(.+)"/ ) {
	    $setwidth_name = lc($1);
#	    print "setwidth_name: $setwidth_name\n";
	}
	elsif ( /^PIXEL_SIZE\s+(\d+)/ ) {
	    $pixel_size = $1;
#	    print "pixel_size: $pixel_size\n";
	}
	elsif ( /^SLANT\s+"(.*)"/ ) {
	    my $slant = lc($1);
#	    print "SLANT $slant\n";
	}
	elsif ( /^DWIDTH\s+(\d+)\s/ ) {
	    $width_sum += $1;
	    $glyphe_count++;
	}
	elsif ( /^AVERAGE_WIDTH\s+(\d+)\s/ ) {
	    $average_width = $1;
	}
    }
    if (!$include_file_version)  {
	print STDERR "ERROR: there is no file Version in the $bdf file!\n";
    }
    if ($font_count != 1) {
	print STDERR "ERROR: there is more than exactly one FONT field in the $bdf file:\n\tFONT ", join ("\n\tFONT ",@font),"\n";
	$error++;
    }
    if ($copyright eq "") {
	print STDERR "ERROR: there is no copyright filed in the $bdf file.\n";
	$error++;
    }
    
    my $weight="";
    if ($weight_name eq "semibold") {
	$weight = "b";
    }
    elsif ($weight_name eq "medium") {
	$weight = "m";
    }
    else {
	print STDERR  "ERROR: unknown weightname: $weight_name in the $bdf file.\n";
	$error++;
    }
    
    my $condense="";
    if ($setwidth_name eq "normal") {
	$condense = "";
    }
    elsif ($setwidth_name eq "condensed") {
	$condense = "c";
    }
    else {
	print STDERR "ERROR: unknown setwidth_name: $setwidth_name in the $bdf file.n";
	$error++;
    }
    
    my $sl = "";
    if ($slant eq "") {
	$sl = "";
    }
    elsif ($slant eq "r") {
	$sl = "";
    }
    elsif ($slant eq "italic") {
	$sl = "i";
    }
    else {
	print STDERR "ERROR: unknown slant: $slant in the $bdf file.\n";
	$error++;
    }
    
    my $alias = "$family_name-$weight$sl$pixel_size$condense";
#    print "ALIAS = $alias\n";
    if ( $average_width != sprintf ("%i",10*$width_sum/$glyphe_count) ) {
	printf STDERR "ERROR: average_width is not the average width of glyphes in the $bdf file:\n\taverage_width=%i\tcomputed=%i\n", $average_width, (10*$width_sum/$glyphe_count);
	$error++;
    }
    if (!defined $fullname) {
	print STDERR "ERROR: no fullname in the $bdf file.\n";
	$error++;
    }
    else {
	printf "%-20s \"%s\"\n", $alias, $fullname;
    }
    
}


exit $error;
