#!/usr/bin/perl -w

# this script takes a list of bdf files as parameters and generates
# copies of these bdf files where startchar values are those
# defined for postscripts (see below the hash ascii2ps)
# the correspondance has been copied from the following doc:
# http://partners.adobe.com/asn/developer/type/pdfs/chsttabl.pdf

# the first param must be a directory
# the other params are bdf filenames

my %ascii2ps =
    (14 => gcid14,
     15 => gcid15,
     16 => gcid16,
     'A4' => 'Euro',
     'B0' => 'degree',
     'C0' => 'Agrave',
     'C2' => 'Acircumflex',
     'C7' => 'Ccedilla',
     'C8' => 'Egrave',
     'C9' => 'Eacute',
     'CA' => 'Ecircumflex',
     'CB' => 'Edieresis',
     'CE' => 'Icircumflex',
     'CF' => 'Idieresis',
     'D4' => 'Ocircumflex',
     'D9' => 'Ugrave',
     'DB' => 'Ucircumflex',
     'DC' => 'Udieresis',
     
     'E0' => 'agrave',
     'E2' => 'acircumflex',
     'E7' => 'ccedilla',
     'E8' => 'egrave',
     'E9' => 'eacute',
     'EA' => 'ecircumflex',
     'EB' => 'edieresis',
     'EE' => 'icircumflex',
     'EF' => 'idieresis',
     'F4' => 'ocircumflex',
     'F9' => 'ugrave',
     'FB' => 'ucircumflex',
     'FC' => 'udieresis',
     );


@from20toXX =
    qw (space exclam quotedbl numbersign dollar percent ampersand quotesingle
	parenleft parenright asterisk plus comma hyphen period slash
	zero one two three four five six seven
	eight nine colon semicolon less equal greater question
	at A B C D E F G
	H I J K L M N O
	P Q R S T U V W
	X Y Z bracketleft backslash bracketright asciicircum underscore
	grave a b c d e f g
	h i j k l m n o
	p q r s t u v w
	x y z braceleft bar braceright	
	);

{ my $i=32;
  foreach my $code (@from20toXX) {
      my $hexi = uc(sprintf ("%x",$i) );
      $ascii2ps{$hexi} = $code;
      $i++;
  }
}



use strict;


my $dir = shift;

die "first arg must be a directory" unless (-d "$dir") ;

my @bdfs = @ARGV;


foreach my $bdf (@bdfs) {
    unless ( open (BDF , $bdf) ) {
	print STDERR "unable to open $bdf\n";
	next;
    }
    my ($filename) = $bdf =~ /([^\/]*)$/ ;
    my ($newbdf) = $dir . "/" . $filename;
    if (-f $newbdf) {
	print STDERR "$newbdf already exists. skipping $bdf\n";
	next;
    }
    unless ( open (NEWBDF, ">$newbdf" )  ) {
	print STDERR "unable to create $newbdf\n";
	next;
    }

    while (<BDF>) {
	next if ( /^STARTCHAR\s+(.+)/ ) ;
	if ( /^ENCODING\s+(.+)/ ) {
	    my $code = $1;
	    my ($ascii) = uc(sprintf ("%x", $code));
	    if (defined $ascii2ps{$ascii}) {
		print NEWBDF "STARTCHAR " . $ascii2ps{$ascii} ."\n";
	    } else {
		print STDERR "unknown asciicode : \"$code (x$ascii)\"\n";
	    }
	}
	print NEWBDF $_;
    }
}

